@@ -30,6 +30,8 @@ namespace validate
 
     const std::size_t MAMBA_SHA256_SIZE_HEX = 64;
     const std::size_t MAMBA_SHA256_SIZE_BYTES = 32;
+    const std::size_t MAMBA_MD5_SIZE_HEX = 32;
+    const std::size_t MAMBA_MD5_SIZE_BYTES = 16;
     const std::size_t MAMBA_ED25519_KEYSIZE_HEX = 64;
     const std::size_t MAMBA_ED25519_KEYSIZE_BYTES = 32;
     const std::size_t MAMBA_ED25519_SIGSIZE_HEX = 128;
@@ -703,7 +705,8 @@ namespace validate
             // std::set<std::string> roles() const override;
             RoleFullKeys self_keys() const override;
 
-            PkgMgrRole create_pkg_mgr() const;
+            PkgMgrRole create_pkg_mgr(const fs::path& p) const;
+            PkgMgrRole create_pkg_mgr(const json& j) const;
 
             /**
              * Return a ``RepoIndexChecker`` implementation (derived class)
